==> abashin.ru.beta.0.0.2.tar.gz: abashin.ru.beta/source/make_beta.sh <==
#!/bin/sh

# Make project
./make.sh

# Create catalog
mkdir -p abashin.ru.beta/distr/dev
mkdir -p abashin.ru.beta/distr/bin

# Move dev part
cd abashin.ru.beta/distr/dev
mv ../../../dev/keyboard ./
mv ../../../dev/keyboard_client ./
mv ../../../dev/keyboard_etalon ./
mv ../../../dev/mouse ./
mv ../../../dev/mouse_client ./
mv ../../../dev/mouse_etalon ./

# Move bin part
cd ../bin
mv ../../../bin/angel/abashin.ru.angel ./
mv ../../../bin/etalon/abashin.ru.etalon ./
mv ../../../bin/report/abashin.ru.report ./
mv ../../../bin/status/abashin.ru.status ./

# Aux files
cd ..
cp ../../bin/abashin.ru.angel.desktop ./
cp ../../bin/abashin.ru.keyboard.desktop ./
cp ../../bin/abashin.ru.mouse.desktop ./
cp ../../bin/etalon.default ./
cp ../../install.sh ./
cp ../../install_root.sh ./
cp ../../uninstall.sh ./
cp ../../uninstall_root.sh ./
cp ../../README.TXT ./

# Add source file
cd ..
mkdir -p source/dev
cd source/dev
cp ../../../dev/* ./
cd ..
mkdir -p bin/angel
cd bin
cp ../../../bin/DataFormat.h ./
cp ../../../bin/angel/*.c ./angel/
cp ../../../bin/angel/*.h ./angel/
cp ../../../bin/angel/*.sh ./angel/
mkdir database
cp ../../../bin/database/*.c ./database/
cp ../../../bin/database/*.h ./database/
cp ../../../bin/database/*.sh ./database/
mkdir etalon
cp ../../../bin/etalon/*.c ./etalon/
cp ../../../bin/etalon/*.h ./etalon/
cp ../../../bin/etalon/*.sh ./etalon/
mkdir report
cp ../../../bin/report/*.c ./report/
cp ../../../bin/report/*.h ./report/
cp ../../../bin/report/*.sh ./report/
mkdir status
cp ../../../bin/status/*.c ./status/
cp ../../../bin/status/*.h ./status/
cp ../../../bin/status/*.sh ./status/
cd ..
cp ../../bin/abashin.ru.angel.desktop ./
cp ../../bin/abashin.ru.keyboard.desktop ./
cp ../../bin/abashin.ru.mouse.desktop ./
cp ../../bin/etalon.default ./
cp ../../install.sh ./
cp ../../install_root.sh ./
cp ../../uninstall.sh ./
cp ../../uninstall_root.sh ./
cp ../../README.TXT ./
cp ../../make.sh ./
cp ../../make_beta.sh ./
echo "done"

==> abashin.ru.beta.0.0.3.tar.gz: abashin.ru.beta/source/make_beta.sh <==
#!/bin/sh

# Make project
./make.sh

# Create catalog
mkdir -p abashin.ru.beta/distr/dev
mkdir -p abashin.ru.beta/distr/bin

# Move dev part
cd abashin.ru.beta/distr/dev
mv ../../../dev/keyboard ./
mv ../../../dev/keyboard_client ./
mv ../../../dev/keyboard_etalon ./
mv ../../../dev/mouse ./
mv ../../../dev/mouse_client ./
mv ../../../dev/mouse_etalon ./

# Move bin part
cd ../bin
mv ../../../bin/angel/abashin.ru.angel ./
mv ../../../bin/etalon/abashin.ru.etalon ./
mv ../../../bin/report/abashin.ru.report ./
mv ../../../bin/status/abashin.ru.status ./

# Aux files
cd ..
cp ../../abashin.ru.angel.desktop ./
cp ../../abashin.ru.keyboard.desktop ./
cp ../../abashin.ru.mouse.desktop ./
cp ../../etalon.default ./
cp ../../install.sh ./
cp ../../install_root.sh ./
cp ../../uninstall.sh ./
cp ../../uninstall_root.sh ./
cp ../../README.TXT ./

# Add source file
cd ..
mkdir -p source/dev
cd source/dev
cp ../../../dev/* ./
cd ..
mkdir -p bin/angel
cd bin
cp ../../../bin/DataFormat.h ./
cp ../../../bin/angel/*.c ./angel/
cp ../../../bin/angel/*.h ./angel/
cp ../../../bin/angel/*.sh ./angel/
mkdir -p database
cp ../../../bin/database/*.c ./database/
cp ../../../bin/database/*.h ./database/
cp ../../../bin/database/*.sh ./database/
mkdir -p etalon
cp ../../../bin/etalon/*.c ./etalon/
cp ../../../bin/etalon/*.h ./etalon/
cp ../../../bin/etalon/*.sh ./etalon/
mkdir -p report
cp ../../../bin/report/*.c ./report/
cp ../../../bin/report/*.h ./report/
cp ../../../bin/report/*.sh ./report/
mkdir -p status
cp ../../../bin/status/*.c ./status/
cp ../../../bin/status/*.h ./status/
cp ../../../bin/status/*.sh ./status/
cd ..
cp ../../abashin.ru.angel.desktop ./
cp ../../abashin.ru.keyboard.desktop ./
cp ../../abashin.ru.mouse.desktop ./
cp ../../etalon.default ./
cp ../../install.sh ./
cp ../../install_root.sh ./
cp ../../uninstall.sh ./
cp ../../uninstall_root.sh ./
cp ../../README.TXT ./
cp ../../make.sh ./
cp ../../make_beta.sh ./
echo "done"
